@@ -2,6 +2,6 @@
 {
      if (length(forecast) != length(true))
          stop("SMDAPE: the lengths of input vectors must be the same.")
-     err = median(200 * (true - forecast) / (true + forecast))
+     err = median(200 * abs(true - forecast) / (true + forecast))
      return(round(err, 6))
 }
